# bioamla

A Python CLI and library for Bioacoustics and Machine Learning Applications.

> **Prerelease Notice:** This is a prerelease version. Do not use on production data.

## Citation

```bibtex
@software{bioamla,
  author = {McMeen, John},
  title = {Bioamla: Bioacoustics and Machine Learning Applications},
  year = {2025},
  url = {https://github.com/jmcmeen/bioamla}
}
```

## License

This project is licensed under the GNU General Public License v3.0 - see the [LICENSE](LICENSE) file for details.
